==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectMapply_unary.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectmapply_unary_h
#define objectmapply_unary_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_mapply_unary_enumeration_name_bw_not,
  adms_mapply_unary_enumeration_name_minus,
  adms_mapply_unary_enumeration_name_not,
  adms_mapply_unary_enumeration_name_plus
} e_mapply_unary_name;
win32_interface char* adms_mapply_unary_tostring_name_impl (p_admsttransform myadmsttransform,e_mapply_unary_name e);
win32_interface e_mapply_unary_name adms_mapply_unary_fromstring_name_impl (p_admsttransform myadmsttransform,char*token);
struct s_mapply_unary {
  t_subexpression _subexpression;
  e_mapply_unary_name _name;
  int _name_isdefault : 1;
  gpointer _arg1;
  int _arg1_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_mapply_unary_getuid (p_mapply_unary mymapply_unary);
win32_interface gboolean adms_mapply_unary_cmp (p_mapply_unary mymapply_unary,p_mapply_unary refmapply_unary);
win32_interface p_mapply_unary adms_mapply_unary_new_1 (e_mapply_unary_name myname,gpointer myarg1);
#define adms_mapply_unary_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_mapply_unary_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_mapply_unary_new_impl (p_adms arguments[]);
win32_interface p_mapply_unary adms_mapply_unary_impl (void* member);
#define adms_mapply_unary(member) ((p_mapply_unary) (member))
#define adms_mapply_unary_new adms_mapply_unary_new_1
#define adms_mapply_unary_isdefault_name(mapply_unary) (adms_mapply_unary(mapply_unary)->_name_isdefault)
#define adms_mapply_unary_valueof_name(mapply_unary) (adms_mapply_unary(mapply_unary)->_name)
#define adms_mapply_unary_isdefault_arg1(mapply_unary) (adms_mapply_unary(mapply_unary)->_arg1_isdefault)
#define adms_mapply_unary_valueof_arg1(mapply_unary) (adms_mapply_unary(mapply_unary)->_arg1)
#define adms_mapply_unary_valueof_subexpression(mapply_unary) ((p_subexpression)mapply_unary)
#define adms_mapply_unary_valueof_math(mapply_unary) ((p_math)mapply_unary)
#define adms_mapply_unary_valueof_adms(mapply_unary) ((p_adms)mapply_unary)
#define adms_mapply_unary_valueto_name(a,b) ((p_mapply_unary)a)->_name=(b)
win32_interface void adms_mapply_unary_valueto_name_impl (p_mapply_unary mymapply_unary,e_mapply_unary_name _name);
#define adms_mapply_unary_valueto_arg1(a,b) ((p_mapply_unary)a)->_arg1=(b)
win32_interface void adms_mapply_unary_valueto_arg1_impl (p_mapply_unary mymapply_unary,gpointer _arg1);
#endif /* objectmapply_unary_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectMapply_unary.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectmapply_unary_h
#define objectmapply_unary_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_mapply_unary_enumeration_name_bw_not,
  adms_mapply_unary_enumeration_name_minus,
  adms_mapply_unary_enumeration_name_not,
  adms_mapply_unary_enumeration_name_plus
} e_mapply_unary_name;
win32_interface char* adms_mapply_unary_tostring_name_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_mapply_unary_name adms_mapply_unary_fromstring_name_impl (p_admsttransform myadmsttransform,char*token);
struct s_mapply_unary {
  t_subexpression _subexpression;
  p_enumeration _name;
  int _name_isdefault : 1;
  p_adms _arg1;
  int _arg1_isdefault : 1;
};
#include <admsObject/objectEnumeration.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_mapply_unary_uid (p_mapply_unary mymapply_unary);
win32_interface int adms_mapply_unary_cmp (p_mapply_unary mymapply_unary,p_mapply_unary refmapply_unary);
win32_interface p_mapply_unary adms_mapply_unary_new(p_enumeration myname,p_adms myarg1);
win32_interface p_adms adms_mapply_unary_new_impl (p_adms arguments[]);
#define adms_mapply_unary(member) ((p_mapply_unary) (member))
#define adms_mapply_unary_isdefault_name(mapply_unary) (adms_mapply_unary(mapply_unary)->_name_isdefault)
#define adms_mapply_unary_valueof_name(mapply_unary) (adms_mapply_unary(mapply_unary)->_name)
#define adms_mapply_unary_isdefault_arg1(mapply_unary) (adms_mapply_unary(mapply_unary)->_arg1_isdefault)
#define adms_mapply_unary_valueof_arg1(mapply_unary) (adms_mapply_unary(mapply_unary)->_arg1)
#define adms_mapply_unary_valueof_subexpression(mapply_unary) ((p_subexpression)mapply_unary)
#define adms_mapply_unary_valueof_math(mapply_unary) ((p_math)mapply_unary)
#define adms_mapply_unary_valueof_adms(mapply_unary) ((p_adms)mapply_unary)
win32_interface inline void adms_mapply_unary_valueto_name (p_mapply_unary mymapply_unary,p_enumeration _name);
win32_interface inline void adms_mapply_unary_valueto_arg1 (p_mapply_unary mymapply_unary,p_adms _arg1);
win32_interface inline void adms_mapply_unary_free(p_mapply_unary mymapply_unary);
#endif /* objectmapply_unary_h */
